@@ -237,7 +237,7 @@ update_foreign_uri (const char *path, const char *account_uri)
 	g_free (new_phy_uri);
 cleanup:
 	g_free (file_path);
-	g_hash_table_destroy (old_props);
+	e_xml_destroy_hash (old_props);
 	return;
 }
 
@@ -587,9 +587,6 @@ account_removed (EAccountList *account_list, EAccount *account)
 			       signals[EXCHANGE_ACCOUNT_REMOVED], 0,
 			       priv->exchange_account);
 
-		g_object_unref (priv->exchange_account);
-		priv->exchange_account = NULL;
-
 		priv->configured_account = NULL;
 		g_free (priv->configured_uri);
 		priv->configured_uri = NULL;
